stickydesign package
====================

Subpackages
-----------

.. toctree::

    stickydesign.params

Submodules
----------

stickydesign\.endclasses module
-------------------------------

.. automodule:: stickydesign.endclasses
    :members:
    :undoc-members:
    :show-inheritance:

stickydesign\.energetics\_basic module
--------------------------------------

.. automodule:: stickydesign.energetics_basic
    :members:
    :undoc-members:
    :show-inheritance:

stickydesign\.energetics\_basic\_old module
-------------------------------------------

.. automodule:: stickydesign.energetics_basic_old
    :members:
    :undoc-members:
    :show-inheritance:

stickydesign\.energetics\_daoe module
-------------------------------------

.. automodule:: stickydesign.energetics_daoe
    :members:
    :undoc-members:
    :show-inheritance:

stickydesign\.multimodel module
-------------------------------

.. automodule:: stickydesign.multimodel
    :members:
    :undoc-members:
    :show-inheritance:

stickydesign\.newparams module
------------------------------

.. automodule:: stickydesign.newparams
    :members:
    :undoc-members:
    :show-inheritance:

stickydesign\.plots module
--------------------------

.. automodule:: stickydesign.plots
    :members:
    :undoc-members:
    :show-inheritance:

stickydesign\.stickydesign module
---------------------------------

.. automodule:: stickydesign.stickydesign
    :members:
    :undoc-members:
    :show-inheritance:

stickydesign\.test\_general module
----------------------------------

.. automodule:: stickydesign.test_general
    :members:
    :undoc-members:
    :show-inheritance:

stickydesign\.version module
----------------------------

.. automodule:: stickydesign.version
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: stickydesign
    :members:
    :undoc-members:
    :show-inheritance:
